package com.ruoyi.branch.mapper;

import com.ruoyi.branch.domain.TBranchMeeting;

import java.util.List;

/**
 * 支部会议管理Mapper接口
 * 
 * @author ruoyi
 * @date 2023-06-07
 */
public interface TBranchMeetingMapper
{
    /**
     * 查询支部会议管理
     * 
     * @param meetingId 支部会议管理主键
     * @return 支部会议管理
     */
    public TBranchMeeting selectTBranchMeetingMgrByMeetingId(Long meetingId);

    /**
     * 查询支部会议管理列表
     * 
     * @param tBranchMeeting 支部会议管理
     * @return 支部会议管理集合
     */
    public List<TBranchMeeting> selectTBranchMeetingMgrList(TBranchMeeting tBranchMeeting);

    /**
     * 新增支部会议管理
     * 
     * @param tBranchMeeting 支部会议管理
     * @return 结果
     */
    public int insertTBranchMeetingMgr(TBranchMeeting tBranchMeeting);

    /**
     * 修改支部会议管理
     * 
     * @param tBranchMeeting 支部会议管理
     * @return 结果
     */
    public int updateTBranchMeetingMgr(TBranchMeeting tBranchMeeting);

    /**
     * 删除支部会议管理
     * 
     * @param meetingId 支部会议管理主键
     * @return 结果
     */
    public int deleteTBranchMeetingMgrByMeetingId(Long meetingId);

    /**
     * 批量删除支部会议管理
     * 
     * @param meetingIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTBranchMeetingMgrByMeetingIds(Long[] meetingIds);
}
